pub struct ServerFnUrlError<E> { /* private fields */ }Expand description
Associates a particular server function error with the server function found at a particular path.
This can be used to pass an error from the server back to the client without JavaScript/WASM supported, by encoding it in the URL as a query string. This is useful for progressive enhancement.
Implementations
Sourceimpl<E: FromServerFnError> ServerFnUrlError<E>
impl<E: FromServerFnError> ServerFnUrlError<E>
Sourcepub fn new(path: impl Display, error: E) -> Self
pub fn new(path: impl Display, error: E) -> Self
Creates a new structure associating the server function at some path with a particular error.
Sourcepub fn to_url(&self, base: &str) -> Result<Url, ParseError>
pub fn to_url(&self, base: &str) -> Result<Url, ParseError>
Adds an encoded form of this server function error to the given base URL.
Sourcepub fn strip_error_info(path: &mut String)
pub fn strip_error_info(path: &mut String)
Replaces any ServerFnUrlError info from the URL in the given string with the serialized success value given.
Sourcepub fn decode_err(err: &str) -> E
pub fn decode_err(err: &str) -> E
Decodes an error from a URL.