WrapError

Struct WrapError 

pub struct WrapError<T>(pub T);
๐Ÿ‘ŽDeprecated since 0.8.0: Now server_fn can return any error type other than ServerFnError, so the WrappedServerError variant will be removed in 0.9.0
Wraps some error type, which may implement any of Error, Clone, or Display.

Tuple Fields

0: T
๐Ÿ‘ŽDeprecated since 0.8.0: Now server_fn can return any error type other than ServerFnError, so the WrappedServerError variant will be removed in 0.9.0