Macro server_fn::server_fn_error
source · macro_rules! server_fn_error { () => { ... }; ($err:expr) => { ... }; }
A helper macro to convert a variety of different types into ServerFnError.
This should mostly be used if you are implementing From<ServerFnError> for YourError.