Module request

Module request 

Types and traits for for HTTP requests.

Modules

actix
Request types for Actix.
axum
Request types for Axum.
browser
Request types for the browser.
generic
This module uses platform-agnostic abstractions allowing users to run server functions on a wide range of platforms.
reqwest
Request types for reqwest.

Structs

BrowserMockReq
A mocked request type that can be used in place of the actual server request, when compiling for the browser.

Traits

ClientReq
Represents a request as made by the client.
Req
Represents the request as received by the server.