pub struct ActixRequest(/* private fields */);Expand description
A wrapped Actix request.
This uses a SendWrapper that allows the Actix HttpRequest type to be Send, but panics
if it it is ever sent to another thread. Actix pins request handling to a single thread, so this
is necessary to be compatible with traits that require Send but should never panic in actual use.
Implementations
Sourceimpl ActixRequest
impl ActixRequest
Sourcepub fn take(self) -> (HttpRequest, Payload)
pub fn take(self) -> (HttpRequest, Payload)
Returns the raw Actix request, and its body.