ServerFnTraitObj

Struct ServerFnTraitObj 

pub struct ServerFnTraitObj<Req, Res> { /* private fields */ }
A trait object that allows multiple server functions that take the same request type and return the same response type to be gathered into a single collection.

Implementations

Source

impl<Req, Res> ServerFnTraitObj<Req, Res>

pub const fn new<S: ServerFn<Server: Server<S::Error, S::InputStreamError, S::OutputStreamError, Request = Req, Response = Res>>>( handler: fn(Req) -> Pin<Box<dyn Future<Output = Res> + Send>>, ) -> Self
where Req: Req<S::Error, S::InputStreamError, S::OutputStreamError, WebsocketResponse = Res> + Send + 'static, Res: TryRes<S::Error> + Send + 'static,

Converts the relevant parts of a server function into a trait object.

pub fn path(&self) -> &'static str

The path of the server function.

pub fn method(&self) -> Method

The HTTP method the server function expects.

pub fn handler(&self, req: Req) -> impl Future<Output = Res> + Send

The handler for this server function.

pub fn middleware(&self) -> MiddlewareSet<Req, Res>

The set of middleware that should be applied to this function.

pub fn boxed(self) -> BoxedService<Req, Res>
where Self: Service<Req, Res>, Req: 'static, Res: 'static,

Converts the server function into a boxed service.