pub enum MultipartData {
Client(BrowserFormData),
Server(Multipart<'static>),
}Expand description
Describes whether the multipart data is on the client side or the server side.
Variants
Implementations
Sourceimpl MultipartData
impl MultipartData
Sourcepub fn into_inner(self) -> Option<Multipart<'static>>
pub fn into_inner(self) -> Option<Multipart<'static>>
Extracts the inner data to handle as a stream.
On the server side, this always returns Some(_). On the client side, always returns None.
Sourcepub fn into_client_data(self) -> Option<BrowserFormData>
pub fn into_client_data(self) -> Option<BrowserFormData>
Extracts the inner form data on the client side.
On the server side, this always returns None. On the client side, always returns Some(_).