Default server function registry
Structs
- A server function that can be called from the client without any context from the server.
Functions
- Attempts to find a server function registered at the given path.
- Returns the set of currently-registered server function paths, for debugging purposes.
Attribute Macros
- Declares that a function is a server function. This means that its body will only run on the server, i.e., when the
ssrfeature is enabled.