pub enum ServerFnErrorErr {
Registration(String),
UnsupportedRequestMethod(String),
Request(String),
ServerError(String),
MiddlewareError(String),
Deserialization(String),
Serialization(String),
Args(String),
MissingArg(String),
Response(String),
}Expand description
Type for errors that can occur when using server functions. If you need to return a custom error type from a server function, implement FromServerFnError for your custom error type.
Variants
Registration(String)
Error while trying to register the server function (only occurs in case of poisoned RwLock).
UnsupportedRequestMethod(String)
Occurs on the client if trying to use an unsupported HTTP method when building a request.
Request(String)
Occurs on the client if there is a network error while trying to run function on server.
ServerError(String)
Occurs when there is an error while actually running the function on the server.
MiddlewareError(String)
Occurs when there is an error while actually running the middleware on the server.
Deserialization(String)
Occurs on the client if there is an error deserializing the server’s response.
Serialization(String)
Occurs on the client if there is an error serializing the server function arguments.
Args(String)
Occurs on the server if there is an error deserializing one of the arguments that’s been sent.
MissingArg(String)
Occurs on the server if there’s a missing argument.
Response(String)
Occurs on the server if there is an error creating an HTTP response.