pub struct BrowserMockServer;Expand description
A mocked server type that can be used in place of the actual server, when compiling for the browser.
Panics
This always panics if its methods are called. It is used solely to stub out the server type when compiling for the client.