pub struct BrowserMockRes;Expand description
A mocked response type that can be used in place of the actual server response, when compiling for the browser.
Panics
This always panics if its methods are called. It is used solely to stub out the server response type when compiling for the client.