pub trait Res<CustErr>where
Self: Sized,{
// Required methods
fn try_from_string(
content_type: &str,
data: String,
) -> Result<Self, ServerFnError<CustErr>>;
fn try_from_bytes(
content_type: &str,
data: Bytes,
) -> Result<Self, ServerFnError<CustErr>>;
fn try_from_stream(
content_type: &str,
data: impl Stream<Item = Result<Bytes, ServerFnError<CustErr>>> + Send + 'static,
) -> Result<Self, ServerFnError<CustErr>>;
fn error_response(path: &str, err: &ServerFnError<CustErr>) -> Self;
fn redirect(&mut self, path: &str);
}Expand description
Represents the response as created by the server;
Required Methods
sourcefn try_from_string(
content_type: &str,
data: String,
) -> Result<Self, ServerFnError<CustErr>>
fn try_from_string( content_type: &str, data: String, ) -> Result<Self, ServerFnError<CustErr>>
Attempts to convert a UTF-8 string into an HTTP response.
sourcefn try_from_bytes(
content_type: &str,
data: Bytes,
) -> Result<Self, ServerFnError<CustErr>>
fn try_from_bytes( content_type: &str, data: Bytes, ) -> Result<Self, ServerFnError<CustErr>>
Attempts to convert a binary blob represented as bytes into an HTTP response.
sourcefn try_from_stream(
content_type: &str,
data: impl Stream<Item = Result<Bytes, ServerFnError<CustErr>>> + Send + 'static,
) -> Result<Self, ServerFnError<CustErr>>
fn try_from_stream( content_type: &str, data: impl Stream<Item = Result<Bytes, ServerFnError<CustErr>>> + Send + 'static, ) -> Result<Self, ServerFnError<CustErr>>
Attempts to convert a stream of bytes into an HTTP response.
sourcefn error_response(path: &str, err: &ServerFnError<CustErr>) -> Self
fn error_response(path: &str, err: &ServerFnError<CustErr>) -> Self
Converts an error into a response, with a 500 status code and the error text as its body.
Object Safety
This trait is not object safe.